pyxmpp2.streambase

Package pyxmpp2 :: Module streambase |
[hide private]

# Module streambase

Core XMPP stream functionality.

Normative reference:
  - RFC 6120

Classes | [hide private]
| StreamBase Base class for a generic XMPP stream.

Functions | [hide private]
_languages_factory(settings) Make the default value of the `languages setting`. |

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.streambase")`
| LANG_SPLIT_RE = `re.compile(r'`(`.`*``)``(?:`-`[`a`-`zA`-`Z0`-`9`]``)``?`-`[`a`-`zA`-`Z0`-`9`]``...``
| ERROR_TAG = ``u'``{http://etherx.jabber.org/streams}error``'``
| FEATURES_TAG = ``u'``{http://etherx.jabber.org/streams}features``'``
| IP_RE = `re.compile(r'^`(``(`\d`+`.`)``{3}`\d`+``)``|``(``[`0`-`9a`-`f`]``*`:`[`0`-`9a`-`f:`]``*`:`[`0`-``...``

Variables Details | [hide private]

  ### LANG_SPLIT_RE Value:
      re.compile(r'(.*)(?:-[a-zA-Z0-9])?-[a-zA-Z0-9]+$')

  ### IP_RE Value:
      re.compile(r'^((\d+.){3}\d+)|([0-9a-f]*:[0-9a-f:]*:[0-9a-f]*)$')